@@ -1,3 +1,4 @@
+import sys
 import colorlog
 from .config import *
 from .data_model import DataModel
@@ -5,8 +6,10 @@ from .simultan_utils import create_component
 from .template_tools import Template, TemplateParser
 from .geo_default_types import BaseGeometricLayer, BaseGeometricVertex, BaseGeometricEdge, BaseGeometricEdgeLoop, BaseGeometricFace, BaseGeometricVolume
 
-from .ParameterStructure.Components import SimComponent
-from .ParameterStructure.Parameters import SimParameter
+print(sys.version)
+
+from ParameterStructure.Components import SimComponent
+from ParameterStructure.Parameters import SimParameter
 
 handler = colorlog.StreamHandler()
 formatter = colorlog.ColoredFormatter(
