@@ -7,29 +7,28 @@ from uuid import uuid4
 from functools import lru_cache
 from weakref import WeakSet
 
-from .SIMULTAN.Project.Services import IAuthenticationService
-from .ParameterStructure import Projects
-from .SIMULTAN.Project.Project import ExtendedProjectData
-from .SIMULTAN.Project.ProjectLoaders import ZipProjectIO
-from .SIMULTAN.UI.Services import ServicesProvider
+from SIMULTAN.Project.Services import IAuthenticationService
+from ParameterStructure import Projects
+from SIMULTAN.Project.Project import ExtendedProjectData
+from SIMULTAN.Project.ProjectLoaders import ZipProjectIO
+from SIMULTAN.UI.Services import ServicesProvider
 
 # from .SIMULTAN.DataExchange import ComponentGeometryExchange
 # from .ParameterStructure.Component import ComponentManagerType
-from .ParameterStructure.Users import *
-from .GeometryViewer import TemporaryGeometryViewerInstance
-from .GeometryViewer.Service import GeometryViewerService
-from .GeometryViewer.Model import *
-from .GeometryViewer.IO import SimGeoIO
-from .GeometryViewer import IGeometryViewerService
+from ParameterStructure.Users import *
+from GeometryViewer import TemporaryGeometryViewerInstance
+from GeometryViewer.Service import GeometryViewerService
+from GeometryViewer.Model import *
+from GeometryViewer.IO import SimGeoIO
+from GeometryViewer import IGeometryViewerService
 from System.Security import SecureString
 from System.IO import FileInfo
 from System import ArgumentOutOfRangeException
-from .ParameterStructure.Components import SimComponent
-from .ParameterStructure.Components import SimSlot, SimSlotBase, SimChildComponentEntry, ComponentUtils
-from .ParameterStructure.Algorithms.Components import ComponentManagement
+from ParameterStructure.Components import SimComponent, SimSlot, SimSlotBase, SimChildComponentEntry, ComponentUtils
+from ParameterStructure.Algorithms.Components import ComponentManagement
 # from .ParameterStructure.Algorithms.Components import ComponentMapping
 # from .ParameterStructure.Parameters import SimParameter
-from .ParameterStructure.Values import SimMultiValueBigTable
+from ParameterStructure.Values import SimMultiValueBigTable
 # from .ParameterStructure.Assets import ContainedResourceFileEntry
 
 
