@@ -534,7 +534,7 @@ class BaseGeometricFace(BaseGeoBaseClass):
 
     @property
     def construction_assignment(self):
-        return next((x for x in self._components if x.InstanceType == 4), None)
+        return next((x for x in self._components if x.InstanceType == SimInstanceType.Attributes2D), None)
 
     @property
     def construction(self):
