@@ -197,7 +197,41 @@ class Template(object):
         return state
 
     def __setstate__(self, d):
+
+        if 'template_name' not in d:
+            raise Exception(f'Template missing value for template_name')
+
+        if 'template_id' not in d:
+            raise Exception(f'Template missing value for template_id')
+
+        # add missing values:
+
+        if 'inherits_from' not in d:
+            d['inherits_from'] = None
+
+        if 'content' not in d:
+            d['content'] = []
+
+        if 'documentation' not in d:
+            d['documentation'] = None
+
+        if 'units' not in d:
+            d['units'] = {}
+
+        if 'types' not in d:
+            d['types'] = {}
+
+        if 'types' not in d:
+            d['types'] = {}
+
+        if 'slots' not in d:
+            d['slots'] = {}
+
+        if 'default_slot' not in d:
+            d['default_slot'] = 'Element'
+
         self.__dict__ = d
+
         self.template_parser = None
         self.template_class = None
 
@@ -205,6 +239,9 @@ class Template(object):
         return f"Template '{self.template_name}': " + object.__repr__(self)
 
 
+yaml.constructor.yaml_constructors['!Template'] = yaml.constructor.yaml_constructors['!Template:']
+
+
 class TemplateParser(object):
 
     bases = {'Liste': SimultanList,
